pub fn register_log_listener<L: LogListener>(listener: L) -> LogGuard<L>Expand description
Register a LogListener that will receive log messages from the core.
This is typically used in headless usage. It can also be used to temporarily log core
messages to something like a file while some analysis is occurring, once the LogGuard is
dropped, the listener will be unregistered.